<?php
/**
 * Contextual functions for the header, footer, content and sidebar classes.
 *
 * @package Gutenix
 */

/**
 * Get container CSS class.
 *
 * @since  1.0.0
 * @param  string $container_type Container type
 * @return string
 */
function gutenix_get_container_class( $container_type = 'boxed' ) {

	if ( 'boxed' === $container_type ) {
		return  'gutenix-container';
	}

	return 'gutenix-container-' . esc_attr( $container_type );
}

/**
 * Prints a CSS class attribute for container based on customize setting.
 *
 * @since  1.0.0
 * @param  string $setting Setting name.
 * @param  array  $classes Additional classes.
 * @return void
 */
function gutenix_container_class_by_setting( $setting = '', $classes = array() ) {

	$container_type = ! empty( $setting ) ? gutenix_theme()->customizer->get_value( $setting ) : 'boxed';

	$classes[] = gutenix_get_container_class( $container_type );

	echo 'class="' . esc_attr( join( ' ', $classes ) ) . '"';
}

/**
 * Prints site content container CSS classes
 *
 * @since  1.0.0
 * @param  array $classes Additional classes.
 * @return void
 */
function gutenix_content_container_class( $classes = array() ) {
	$layout_type    = gutenix_theme()->customizer->get_value( 'layout_type' );
	$container_type = ! empty( gutenix_theme()->layout[ $layout_type ]['container'] ) ? gutenix_theme()->layout[ $layout_type ]['container'] : 'boxed';

	$classes[] = gutenix_get_container_class( $container_type );

	$classes = apply_filters( 'gutenix_content_container_class', $classes );

	echo 'class="' . esc_attr( join( ' ', $classes ) ) . '"';
}

/**
 * Prints primary content wrapper CSS classes.
 *
 * @since  1.0.0
 * @param  array $classes Additional classes.
 * @return void
 */
function gutenix_primary_content_class( $classes = array() ) {
	echo 'class="' . esc_attr( join( ' ', gutenix_get_layout_classes( 'content', $classes ) ) ) . '"';
}

/**
 * Prints secondary content wrapper CSS classes.
 *
 * @since  1.0.0
 * @param  array $classes Additional classes.
 * @return void
 */
function gutenix_secondary_content_class( $classes = array() ) {
	echo 'class="' . esc_attr( join( ' ', gutenix_get_layout_classes( 'sidebar', $classes ) ) ) . '"';
}

/**
 * Get CSS class attribute for passed layout context.
 *
 * @since  1.0.0
 * @param  string $layout  Layout context.
 * @param  array  $classes Additional classes.
 * @return array
 */
function gutenix_get_layout_classes( $layout = 'content', $classes = array() ) {
	$layout_type    = gutenix_theme()->customizer->get_value( 'layout_type' );
	$layout_classes = ! empty( gutenix_theme()->layout[ $layout_type ][ $layout ] ) ? gutenix_theme()->layout[ $layout_type ][ $layout ] : array();

	if ( ! empty( $classes ) ) {
		$layout_classes = array_merge( $classes, $layout_classes );
	}

	if ( empty( $layout_classes ) ) {
		return array();
	}

	return apply_filters( "gutenix_{$layout}_classes", $layout_classes );
}

/**
 * Retrieve or print `class` attribute for Post List wrapper.
 *
 * @since  1.0.0
 * @param  array $classes Additional classes.
 * @return void
 */
function gutenix_posts_list_class( $classes = array() ) {

	$classes[] = 'posts-list';

	$layout = apply_filters( 'gutenix_posts_list_layout', 'default' );

	$classes[] = 'posts-list--' . esc_attr( $layout );

	$classes = apply_filters( 'gutenix_posts_list_class', $classes );

	echo 'class="' . esc_attr( join( ' ', $classes ) ) . '"';
}

/**
 * Get page title classes.
 *
 * @since  1.0.0
 * @param  array $classes Additional classes.
 * @return string
 */
function gutenix_get_page_title_class( $classes = array() ) {
	$classes[] = 'entry-title';

	$show_page_title = gutenix_theme()->customizer->get_value( 'show_page_title' );

	if ( ! $show_page_title ) {
		$classes[] = 'screen-reader-text';
	}

	$classes = apply_filters( 'gutenix_get_page_title_class', $classes );

	return 'class="' . esc_attr( join( ' ', $classes ) ) . '"';
}

/**
 * Prints site header bar CSS classes.
 *
 * @since  1.0.0
 * @param  array $classes Additional classes.
 * @return void
 */
function gutenix_header_bar_class( $classes = array() ) {
	$layout = gutenix_theme()->customizer->get_value( 'header_layout_type' );
	$mobile_breakpoint = gutenix_get_mobile_panel_breakpoint();

	$classes[] = 'header-bar';
	$classes[] = 'header-bar--' . esc_attr( $layout );

	if ( $mobile_breakpoint ) {
		$classes[] = 'header-bar--mobile-breakpoint-' . esc_attr( $mobile_breakpoint );
	}

	// Need for render header partial in the customizer.
	if ( 'disable' === $layout ) {
		$classes[] = 'gutenix-hidden';
	}

	$classes = apply_filters( 'gutenix_header_bar_class', $classes );

	echo 'class="' . esc_attr( join( ' ', $classes ) ) . '"';
}

/**
 * Prints site footer bar CSS classes.
 *
 * @since  1.0.0
 * @param  array $classes Additional classes.
 * @return void
 */
function gutenix_footer_bar_class( $classes = array() ) {
	$layout = gutenix_theme()->customizer->get_value( 'footer_layout_type' );

	$classes[] = 'footer-bar';
	$classes[] = 'footer-bar--' . esc_attr( $layout );

	// Need for render footer partial in the customizer.
	if ( 'disable' === $layout ) {
		$classes[] = 'gutenix-hidden';
	}

	$classes = apply_filters( 'gutenix_footer_bar_class', $classes );

	echo 'class="' . esc_attr( join( ' ', $classes ) ) . '"';
}
