<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Gutenix
 */

// Add a pingback url auto-discovery header for single posts, pages, or attachments.
add_action( 'wp_head', 'gutenix_pingback_header' );

// Adds the meta theme-color to the header.
add_action( 'wp_head', 'gutenix_meta_theme_color' );

// Enqueue misc js script.
add_filter( 'gutenix_theme_script_depends', 'gutenix_enqueue_misc_js_script' );

// Adds custom classes to the array of body classes.
add_filter( 'body_class', 'gutenix_body_classes' );

// Sidebars classes.
add_filter( 'gutenix_widget_area_classes', 'gutenix_set_sidebar_classes', 10, 2 );

// Set footer columns.
add_filter( 'dynamic_sidebar_params', 'gutenix_set_footer_widget_layout' );

// Modify fonts list.
add_filter( 'gutenix_cx_customizer/fonts_list', 'gutenix_modify_fonts_list' );

// Modify fonts data.
add_filter( 'gutenix_cx_fonts_manager/fonts_data', 'gutenix_modify_fonts_data', 10, 2 );

// Modify a comment form.
add_filter( 'comment_form_defaults', 'gutenix_modify_comment_form' );

// Add dynamic css functions.
add_filter( 'gutenix_cx_dynamic_css/func_list', 'gutenix_add_dynamic_css_functions' );

// Disable print `Recent comments` widget style.
add_filter( 'show_recent_comments_widget_style', '__return_false' );

// Customization for `Tag Cloud` widget.
add_filter( 'widget_tag_cloud_args', 'gutenix_customize_tag_cloud' );

// Set specific customizer settings.
add_filter( 'theme_mod_layout_type', 'gutenix_set_specific_layout_type' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 *
 * @since  1.0.0
 * @return void
 */
function gutenix_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}

/**
 * Adds the meta theme-color to the header.
 *
 * @since  1.0.0
 * @return void
 */
function gutenix_meta_theme_color() {
	$theme_color = gutenix_theme()->customizer->get_value( 'address_bar_color' );

	echo '<meta name="theme-color" content="' . esc_attr( $theme_color ) . '"/>' . "\n";
}

/**
 * Enqueue misc js script.
 *
 * @since  1.0.0
 * @param  array $depends Default dependencies.
 * @return array
 */
function gutenix_enqueue_misc_js_script( $depends = array() ) {

	$totop_visibility = gutenix_theme()->customizer->get_value( 'show_totop_button' );

	if ( $totop_visibility ) {
		$depends[] = 'jquery-ui-totop';
	}

	return $depends;
}

/**
 * Adds custom classes to the array of body classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the body element.
 * @return array
 */
function gutenix_body_classes( $classes ) {

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	$layout_type = gutenix_theme()->customizer->get_value( 'layout_type' );

	$classes[] = 'page-layout-' . esc_attr( $layout_type );

	if ( gutenix_has_sidebar() ) {
		$classes[] = 'has-sidebar';
	} else {
		$classes[] = 'no-sidebar';
	}

	//	Site Title, Description Hidden
	if ( ! has_custom_logo() && display_header_text() == false ) {
		$classes[] = 'no-site-title';
	}

	$show_site_desc 	= gutenix_theme()->customizer->get_value( 'show_tagline' );
	$site_desc 			= get_bloginfo( 'description', 'display' );
	$visible_desc 		= $show_site_desc && $site_desc;
	if ( ! $visible_desc ) {
		$classes[] = 'no-site-description';
	}

	return $classes;
}

/**
 * Set layout classes for sidebars.
 *
 * @since  1.0.0
 * @uses   gutenix_get_layout_classes.
 *
 * @param  array  $classes Additional classes.
 * @param  string $area_id Sidebar ID.
 * @return array
 */
function gutenix_set_sidebar_classes( $classes, $area_id ) {

	if ( in_array( $area_id, array( 'sidebar', 'sidebar-shop' ) ) ) {

		if ( $area_id === 'sidebar-shop' ) {
			$classes[] = 'sidebar';
		}

		return gutenix_get_layout_classes( 'sidebar', $classes );
	}

	if ( 'footer-area' == $area_id ) {
		$columns = gutenix_theme()->customizer->get_value( 'footer_widgets_columns' );

		$classes[] = sprintf( 'footer-area--%s-cols', esc_attr( $columns ) );
		$classes[] = 'gutenix-row';
	}

	return $classes;
}

/**
 * Get footer widgets layout class
 *
 * @since  1.0.0
 * @param  string $params Existing widget classes.
 * @return string
 */
function gutenix_set_footer_widget_layout( $params ) {

	if ( is_admin() ) {
		return $params;
	}

	if ( empty( $params[0]['id'] ) || 'footer-area' !== $params[0]['id'] ) {
		return $params;
	}

	if ( empty( $params[0]['before_widget'] ) ) {
		return $params;
	}

	$columns = gutenix_theme()->customizer->get_value( 'footer_widgets_columns' );

	$columns = intval( $columns );
	$classes = 'class="gutenix-col-xs-12 gutenix-col-md-%2$s gutenix-col-xl-%1$s ';

	switch ( $columns ) {
		case 4:
			$xl_col = 3;
			$md_col = 6;
			break;

		case 3:
			$xl_col = 4;
			$md_col = 4;
			break;

		case 2:
			$xl_col = 6;
			$md_col = 6;
			break;

		default:
			$xl_col = 12;
			$md_col = 12;
			break;
	}

	$params[0]['before_widget'] = str_replace(
		'class="',
		sprintf( $classes, $xl_col, $md_col ),
		$params[0]['before_widget']
	);

	return $params;
}

/**
 * Modify fonts list.
 *
 * @since  1.0.0
 * @param  array $fonts Fonts List.
 * @return array
 */
function gutenix_modify_fonts_list( $fonts = array() ) {

	$fonts = array_merge(
		array(
			'-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif' => esc_html__( 'Default System Font', 'gutenix' ),
		),
		$fonts
	);

	return $fonts;
}

/**
 * Modify fonts data. Added italic, bold and bold-italic styles.
 *
 * @since  1.0.0
 * @param  array $data Fonts data.
 * @param  array $args Fonts manager arguments.
 * @return array
 */
function gutenix_modify_fonts_data( $data = array(), $args = array() ) {

	if ( ! isset( $args['prefix'] ) || ( 'gutenix' !== $args['prefix'] ) ) {
		return $data;
	}

	foreach ( $data as $font_family => $font_args ) {

		foreach ( $font_args['style'] as $font_style ) {
			if ( ! strpos( $font_style, 'italic' ) && ! in_array( $font_style . 'italic', $font_args['style'] ) ) {
				$data[ $font_family ]['style'][] = $font_style . 'italic';
			}
		}

		if ( ! in_array( '700', $data[ $font_family ]['style'] ) ) {
			$data[ $font_family ]['style'][] = '700';
		}

		if ( ! in_array( '700italic', $data[ $font_family ]['style'] ) ) {
			$data[ $font_family ]['style'][] = '700italic';
		}
	}

	return $data;
}

/**
 * Modify a comment form.
 *
 * @since  1.0.0
 * @param  array $args Arguments for comment form.
 * @return array
 */
function gutenix_modify_comment_form( $args ) {
	$args = wp_parse_args( $args );

	if ( ! isset( $args['format'] ) ) {
		$args['format'] = current_theme_supports( 'html5', 'comment-form' ) ? 'html5' : 'xhtml';
	}

	$req       = get_option( 'require_name_email' );
	$aria_req  = ( $req ? " aria-required='true'" : '' );
	$html_req  = ( $req ? " required='required'" : '' );
	$html5     = 'html5' === $args['format'];
	$commenter = wp_get_current_commenter();

	$args['label_submit'] = esc_html__( 'Submit', 'gutenix' );

	$args['fields']['author'] = '<p class="comment-form-author"><label for="author">' . esc_html__( 'Your name', 'gutenix' ) . ( $req ? ' <span class="required">*</span>' : '' ) . '</label><input id="author" class="comment-form__field" name="author" type="text" placeholder="' . esc_attr__( 'Name', 'gutenix' ) . '" value="' . esc_attr( $commenter['comment_author'] ) . '" size="100"' . $aria_req . $html_req . ' /></p>';

	$args['fields']['email'] = '<p class="comment-form-email"><label for="email">' . esc_html__( 'Your email', 'gutenix' ) . ( $req ? ' <span class="required">*</span>' : '' ) . '</label><input id="email" class="comment-form__field" name="email" ' . ( $html5 ? 'type="email"' : 'type="text"' ) . ' placeholder="' . esc_attr__( 'Email address', 'gutenix' ) . '" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="100" aria-describedby="email-notes"' . $aria_req . $html_req . ' /></p>';

	$args['fields']['url'] = '<p class="comment-form-url"><label for="url">' . esc_html__( 'Your website', 'gutenix' ) . '</label><input id="url" class="comment-form__field" name="url" ' . ( $html5 ? 'type="url"' : 'type="text"' ) . ' placeholder="' . esc_attr__( 'Website', 'gutenix' ) . '" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="100" /></p>';

	$args['comment_field'] = '<p class="comment-form-comment"><label for="comment">' . esc_html__( 'Your comment', 'gutenix' ) . '</label><textarea id="comment" class="comment-form__field" name="comment" placeholder="' . esc_attr__( 'Comment', 'gutenix' ) . '" cols="45" rows="8" aria-required="true" required="required"></textarea></p>';

	$args['title_reply_before'] = '<h3 id="reply-title" class="comment-reply-title">';

	$args['title_reply_after'] = '</h3>';

	$args['class_submit'] = 'submit btn btn-primary';

	return $args;
}

/**
 * Add custom dynamic css functions.
 *
 * @since  1.0.0
 * @param  array $func_list Functions list.
 * @return array
 */
function gutenix_add_dynamic_css_functions( $func_list = array() ) {

	$func_list['fallback_var']   = 'gutenix_dynamic_fallback_var';
	$func_list['css_property']   = 'gutenix_dynamic_css_property';
	$func_list['background_img'] = 'gutenix_dynamic_background_image';

	return $func_list;
}


/**
 * Callback function for dynamic css function `fallback_var`.
 *
 * @since  1.0.0
 * @param  string $value         Value.
 * @param  string $default_value Default value.
 * @return string
 */
function gutenix_dynamic_fallback_var( $value = '', $default_value = '' ) {

	if ( empty( $value ) ) {
		return $default_value;
	}

	return $value;
}

/**
 * Callback function for dynamic css function `css_property`.
 *
 * @since  1.0.0
 * @param  string     $property  CSS-property name.
 * @param  string|int $value CSS-property value.
 * @return string|bool
 */
function gutenix_dynamic_css_property( $property = '', $value = '' ) {

	if ( empty( $value ) ) {
		return false;
	}

	return $property . ': ' . $value;
}

/**
 * Callback function for dynamic css function `bg_img`.
 *
 * @since  1.0.0
 * @param  string $img        Background Image
 * @param  string $size       Background Size
 * @param  string $position   Background Position
 * @param  string $repeat     Background Repeat
 * @param  string $attachment Background Attachment
 * @return string|bool
 */
function gutenix_dynamic_background_image( $img = null, $size = null, $position = null, $repeat = null, $attachment = null ) {

	if ( empty( $img ) ) {
		return false;
	}

	$css_map = array(
		'background-image'      => 'url(' . esc_url( $img ) . ')',
		'background-size'       => $size,
		'background-position'   => str_replace( '-', ' ', $position ),
		'background-repeat'     => $repeat,
		'background-attachment' => $attachment,
	);

	$result_map = array();

	foreach ( $css_map as $property => $value ) {

		if ( empty( $value ) ) {
			continue;
		}

		$result_map[] = $property . ':' . $value;
	}

	$result = join( ';', $result_map );

	return $result;
}

/**
 * Customization for `Tag Cloud` widget.
 *
 * @since  1.0.0
 * @param  array $args Widget arguments.
 * @return array
 */
function gutenix_customize_tag_cloud( $args ) {
	$args['smallest'] = 16;
	$args['largest']  = 16;
	$args['unit']     = 'px';

	return $args;
}

/**
 * Set specific layout type.
 *
 * @since  1.0.0
 * @param  string $value Default value.
 * @return string
 */
function gutenix_set_specific_layout_type( $value = '' ) {

	if ( is_search() ) {
		return 'boxed-full-width';
	}

	if ( is_page() ) {
		$page_layout = gutenix_theme()->customizer->get_value( 'layout_type_pages' );

		if ( ! empty( $page_layout ) ) {
			return $page_layout;
		}
	}

	if ( is_home() || ( is_archive() && ! is_tax() && ! is_post_type_archive() ) ) {
		$blog_layout = gutenix_theme()->customizer->get_value( 'layout_type_blog' );

		if ( ! empty( $blog_layout ) ) {
			return $blog_layout;
		}
	}

	if ( is_singular( 'post' ) ) {
		$post_layout = gutenix_theme()->customizer->get_value( 'layout_type_post' );

		if ( ! empty( $post_layout ) ) {
			return $post_layout;
		}
	}

	return $value;
}
