<?php
/**
 * Extends basic functionality for better WooCommerce compatibility
 *
 * @package Gutenix
 */

/**
 * WooCommerce setup function.
 *
 * @link https://docs.woocommerce.com/document/third-party-custom-theme-compatibility/
 * @link https://github.com/woocommerce/woocommerce/wiki/Enabling-product-gallery-features-(zoom,-swipe,-lightbox)-in-3.0.0
 *
 * @return void
 */
function gutenix_wc_setup() {
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}

add_action( 'after_setup_theme', 'gutenix_wc_setup' );

/**
 * Add 'woocommerce-active' class to the body tag.
 *
 * @param  array $classes CSS classes applied to the body tag.
 *
 * @return array $classes modified to include 'woocommerce-active' class.
 */
function gutenix_wc_active_body_class( $classes ) {
	$classes[] = 'woocommerce-active';

	return $classes;
}

add_filter( 'body_class', 'gutenix_wc_active_body_class' );

/**
 * Related Products Args.
 *
 * @param array $args related products args.
 *
 * @return array $args related products args.
 */
function gutenix_wc_related_products_args( $args ) {
	$defaults = array(
		'posts_per_page' => 4,
		'columns'        => 4,
	);

	$args = wp_parse_args( $defaults, $args );

	return $args;
}

add_filter( 'woocommerce_output_related_products_args', 'gutenix_wc_related_products_args' );

/**
 * Remove default WooCommerce wrapper.
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );

if ( ! function_exists( 'gutenix_wc_wrapper_before' ) ) {
	/**
	 * Before Content.
	 *
	 * Wraps all WooCommerce content in wrappers which match the theme markup.
	 *
	 * @return void
	 */
	function gutenix_wc_wrapper_before() {
		?>
			<div <?php gutenix_content_container_class( array( 'site-content__container' ) ); ?>>
			<div class="gutenix-row">
			<div id="primary" <?php gutenix_primary_content_class( array( 'content-area' ) ); ?>>
			<main id="main" class="site-main">
		<?php
	}
}

add_action( 'woocommerce_before_main_content', 'gutenix_wc_wrapper_before' );

if ( ! function_exists( 'gutenix_wc_wrapper_after' ) ) {
	/**
	 * After Content.
	 *
	 * Closes the wrapping divs.
	 *
	 * @return void
	 */
function gutenix_wc_wrapper_after() {
	?>
	</main><!-- #main -->
	</div><!-- #primary -->
	<?php
}
}
add_action( 'woocommerce_after_main_content', 'gutenix_wc_wrapper_after' );


if ( ! function_exists( 'gutenix_wc_sidebar_after' ) ) {
	/**
	 * Close tags after sidebar
	 */
	function gutenix_wc_sidebar_after() {
		?>
			</div>
			</div>
		<?php
	}
}
add_action( 'woocommerce_sidebar', 'gutenix_wc_sidebar_after', 99 );


/**
 * Sample implementation of the WooCommerce Mini Cart.
 *
 * You can add the WooCommerce Mini Cart to header.php like so ...
 *
 * <?php
 * if ( function_exists( 'gutenix_wc_header_cart' ) ) {
 * gutenix_wc_header_cart();
 * }
 * ?>
 */

if ( ! function_exists( 'gutenix_wc_cart_link_fragment' ) ) {
	/**
	 * Cart Fragments.
	 *
	 * Ensure cart contents update when products are added to the cart via AJAX.
	 *
	 * @param array $fragments Fragments to refresh via AJAX.
	 *
	 * @return array Fragments to refresh via AJAX.
	 */
	function gutenix_wc_cart_link_fragment( $fragments ) {
		ob_start();
		gutenix_wc_cart_link();
		$fragments['a.header-cart__link'] = ob_get_clean();

		return $fragments;
	}
}
add_filter( 'add_to_cart_fragments', 'gutenix_wc_cart_link_fragment' );

if ( ! function_exists( 'gutenix_wc_cart_link' ) ) {
	/**
	 * Cart Link.
	 *
	 * Displayed a link to the cart including the number of items present and the cart total.
	 *
	 * @return void
	 */
	function gutenix_wc_cart_link() {
		?>
			<a class="header-cart__link" href="#" title="<?php esc_attr_e( 'View your shopping cart', 'gutenix' ); ?>">
		  <?php
		  $item_count_text = sprintf(
		  /* translators: number of items in the mini cart. */
			  esc_html( '%d' ),
			  WC()->cart->get_cart_contents_count()
		  );

		  ?>
				<svg class="svg-icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16"><path d="M15.0386 3H4.51157L4.01028 0.796875C3.95806 0.546875 3.83796 0.354167 3.64998 0.21875C3.47244 0.0729167 3.25835 0 3.00771 0H0V2H2.20879L4.01028 10.2031C4.0625 10.4531 4.17738 10.651 4.35491 10.7969C4.5429 10.9323 4.76221 11 5.01285 11H13.0334C13.2318 11 13.4198 10.9323 13.5974 10.7969C13.7749 10.6615 13.8898 10.4948 13.942 10.2969L15.9471 4.29688C16.0411 4.04688 16.0098 3.77083 15.8531 3.46875C15.7069 3.15625 15.4354 3 15.0386 3ZM7.01799 14C7.01799 14.5521 6.81956 15.0208 6.42271 15.4062C6.03631 15.8021 5.56635 16 5.01285 16C4.45935 16 3.98417 15.8021 3.58732 15.4062C3.20091 15.0208 3.00771 14.5521 3.00771 14C3.00771 13.4479 3.20091 12.9792 3.58732 12.5938C3.98417 12.1979 4.45935 12 5.01285 12C5.56635 12 6.03631 12.1979 6.42271 12.5938C6.81956 12.9792 7.01799 13.4479 7.01799 14ZM15.0386 14C15.0386 14.5521 14.8401 15.0208 14.4433 15.4062C14.0569 15.8021 13.5869 16 13.0334 16C12.4799 16 12.0047 15.8021 11.6079 15.4062C11.2215 15.0208 11.0283 14.5521 11.0283 14C11.0283 13.4479 11.2215 12.9792 11.6079 12.5938C12.0047 12.1979 12.4799 12 13.0334 12C13.5869 12 14.0569 12.1979 14.4433 12.5938C14.8401 12.9792 15.0386 13.4479 15.0386 14Z"/></svg>
				<span class="header-cart__link-count"><?php echo esc_html( $item_count_text ); ?></span>
			</a>
		<?php
	}
}

if ( ! function_exists( 'gutenix_wc_header_cart' ) ) {
	/**
	 * Display Header Cart.
	 *
	 * @return void
	 */
	function gutenix_wc_header_cart() {
		if ( is_cart() ) {
			$class = 'current-menu-item';
		} else {
			$class = '';
		}
		?>
			<div class="header-cart">
				<div class="header-cart__link-wrap <?php echo esc_attr( $class ); ?>">
			<?php gutenix_wc_cart_link(); ?>
				</div>
				<div class="header-cart__content">
			<?php
			$instance = array( 'title' => esc_html__( 'My cart', 'gutenix' ) );
			the_widget( 'WC_Widget_Cart', $instance );
			?>
				</div>
			</div>
		<?php
	}
}

add_action( 'gutenix_header_wc_cart', 'gutenix_wc_header_cart' );

if ( ! function_exists( 'gutenix_wc_pagination' ) ) {

	/**
	 * WooCommerce pagination
	 *
	 * @param $args
	 *
	 * @return mixed
	 */
	function gutenix_wc_pagination( $args ) {

		$prev_icon = is_rtl() ? 'icon-next' : 'icon-prev';
		$next_icon = is_rtl() ? 'icon-prev' : 'icon-next';

		$args['prev_text'] = sprintf( '<span class="nav-icon %2$s"></span><span>%1$s</span>', esc_html__( 'Prev', 'gutenix' ), $prev_icon );

		$args['next_text'] = sprintf( '<span>%1$s</span><span class="nav-icon %2$s"></span>', esc_html__( 'Next', 'gutenix' ), $next_icon );

		return $args;
	}

}
add_filter( 'woocommerce_pagination_args', 'gutenix_wc_pagination' );

if ( ! function_exists( 'gutenix_wc_product_search_form' ) ) {

	/**
	 * WooCommerce search form
	 *
	 * @param $args
	 *
	 * @return mixed
	 */
	function gutenix_wc_product_search_form( $html ) {
		$format = apply_filters( 'gutenix_product_search_form_submit_format', '<button type="submit" value="Search">%s</button>' );

		$search_button = sprintf( $format, gutenix_get_icon_svg( 'search' ) );
		$pattern = '/<button[^>]*>.*?<\/button>/i';
		$html = preg_replace( $pattern, $search_button, $html );

		return $html;
	}

}
add_filter( 'get_product_search_form', 'gutenix_wc_product_search_form' );