<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Gutenix
 */

if ( ! function_exists( 'gutenix_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * @since  1.0.0
	 * @param  array $args Arguments.
	 * @return string|bool
	 */
	function gutenix_post_thumbnail( $args = array() ) {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return false;
		}

		$default_args = array(
			'size'       => 'post-thumbnail',
			'link'       => false,
			'class'      => 'post-thumbnail',
			'link-class' => 'post-thumbnail__link',
			'echo'       => true,
			'visible'    => true,
		);

		$args = wp_parse_args( $args, $default_args );
		$args = apply_filters( 'gutenix_post_thumbnail_args', $args );

		$visible = filter_var( $args['visible'], FILTER_VALIDATE_BOOLEAN );

		if ( ! $visible ) {
			return false;
		}

		$thumb_format = '<figure class="%2$s">%1$s</figure><!-- .post-thumbnail -->';

		if ( $args['link'] ) {
			$thumb_format = '<figure class="%2$s"><a class="%3$s" href="%4$s" aria-hidden="true" tabindex="-1">%1$s</a></figure><!-- .post-thumbnail -->';
		}

		$thumb_format = apply_filters( 'gutenix_post_thumbnail_format', $thumb_format, $args );

		$thumb_output = apply_filters( 'gutenix_post_thumbnail_output', sprintf(
			$thumb_format,
			get_the_post_thumbnail( null, esc_attr( $args['size'] ) ),
			esc_attr( $args['class'] ),
			esc_attr( $args['link-class'] ),
			esc_url( get_the_permalink() )
		) );

		return Gutenix_Utils::output_method( $thumb_output, $args['echo'] );
	}
endif;

if ( ! function_exists( 'gutenix_post_excerpt' ) ) :
	/**
	 * Prints HTML with excerpt.
	 *
	 * @since  1.0.0
	 * @param  array $args Arguments.
	 * @return string|bool
	 */
	function gutenix_post_excerpt( $args = array() ) {
		$default_args = array(
			'before'  => '<div class="entry-content"><p>',
			'after'   => '</p></div><!-- .entry-content -->',
			'echo'    => true,
			'visible' => gutenix_theme()->customizer->get_value( 'blog_post_excerpt' ),
			'length'  => gutenix_theme()->customizer->get_value( 'blog_post_excerpt_words_count' ),
		);

		$args = wp_parse_args( $args, $default_args );
		$args = apply_filters( 'gutenix_post_excerpt_args', $args );

		$visible = filter_var( $args['visible'], FILTER_VALIDATE_BOOLEAN );

		if ( ! $visible ) {
			return false;
		}

		$words_count = ! empty( $args['length'] ) ? (int) $args['length'] : 20;
		$more        = apply_filters( 'gutenix_post_excerpt_more_text', '&hellip;' );

		if ( has_excerpt() ) {
			$excerpt = wp_trim_words( get_the_excerpt(), $words_count, $more );
		} else if ( is_search() ) {
			$excerpt = wp_trim_words( get_the_excerpt(), 20 );
		} else if ( is_singular( 'post' ) ) {
			$excerpt = wp_trim_words( get_the_excerpt(), $words_count );
		} else {
			$excerpt = the_content( '' );
			$excerpt = strip_shortcodes( $excerpt );
			$excerpt = str_replace( ']]>', ']]&gt;', $excerpt );
			$excerpt = wp_trim_words( $excerpt, $words_count, $more );
		}

		if ( ! $excerpt ) {
			return false;
		}

		$excerpt_output = apply_filters(
			'gutenix_post_excerpt_output',
			$args['before'] . $excerpt . $args['after']
		);

		return Gutenix_Utils::output_method( $excerpt_output, $args['echo'] );
	}
endif;

if ( ! function_exists( 'gutenix_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 *
	 * @since  1.0.0
	 * @param  array $args Arguments.
	 * @return string|bool
	 */
	function gutenix_posted_on( $args = array() ) {
		if ( 'post' !== get_post_type() ) {
			return false;
		}

		$default_args = array(
			'prefix'  => esc_html_x( 'Posted', 'post date prefix', 'gutenix' ),
			'format'  => '',
			'before'  => '<span class="posted-on">',
			'after'   => '</span>',
			'echo'    => true,
			'visible' => ! is_singular( 'post' ) ? gutenix_theme()->customizer->get_value( 'blog_post_publish_date' ) : gutenix_theme()->customizer->get_value( 'single_post_publish_date' ),
		);

		$args = wp_parse_args( $args, $default_args );
		$args = apply_filters( 'gutenix_posted_on_args', $args );

		$visible = filter_var( $args['visible'], FILTER_VALIDATE_BOOLEAN );

		if ( ! $visible ) {
			return false;
		}

		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$format = esc_attr( $args['format'] );

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date( $format ) ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date( $format ) )
		);

		$time = get_the_time( 'Y-m-d\TH:i:sP' );

		preg_match_all( '/(\d+)/mi', $time, $date_array );
		$link = get_day_link( (int) $date_array[0][0], (int) $date_array[0][1], (int) $date_array[0][2] );

		$posted_on = sprintf(
			'<a href="%1$s" rel="bookmark">%2$s</a>',
			esc_url( $link ),
			$time_string
		);

		if ( ! empty( $args['prefix'] ) ) {
			$args['prefix'] = $args['prefix'] . ' ';
		}

		$posted_on_output = apply_filters(
			'gutenix_posted_on_output',
			$args['before'] . $args['prefix'] . $posted_on . $args['after']
		);

		return Gutenix_Utils::output_method( $posted_on_output, $args['echo'] );
	}
endif;

if ( ! function_exists( 'gutenix_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 *
	 * @since  1.0.0
	 * @param  array $args Arguments.
	 * @return string|bool
	 */
	function gutenix_posted_by( $args = array() ) {
		if ( 'post' !== get_post_type() ) {
			return false;
		}

		$default_args = array(
			'prefix'      => esc_html_x( 'by', 'post author prefix', 'gutenix' ),
			'before'      => '<span class="byline">',
			'after'       => '</span>',
			'avatar'      => false,
			'avatar_size' => 60,
			'echo'        => true,
			'visible'     => ! is_singular( 'post' ) ? gutenix_theme()->customizer->get_value( 'blog_post_author' ) : gutenix_theme()->customizer->get_value( 'single_post_author' ),
		);

		$args = wp_parse_args( $args, $default_args );
		$args = apply_filters( 'gutenix_posted_by_args', $args );

		$visible = filter_var( $args['visible'], FILTER_VALIDATE_BOOLEAN );

		if ( ! $visible ) {
			return false;
		}

		$avatar = '';

		if ( $args['avatar'] ) {
			$avatar = get_avatar( get_the_author_meta( 'user_email' ), esc_attr( $args['avatar_size'] ), '', esc_attr( get_the_author_meta( 'nickname' ) ) );
		}

		if ( ! empty( $args['prefix'] ) ) {
			$args['prefix'] = $args['prefix'] . ' ';
		}

		$byline_format = apply_filters(
			'gutenix_posted_byline_format',
			'<span class="author vcard">%3$s<a class="url fn n" href="%1$s">%2$s</a></span>'
		);

		$byline = sprintf(
			$byline_format,
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			esc_html( get_the_author() ),
			$args['prefix']
		);

		$posted_by_output = apply_filters(
			'gutenix_posted_by_output',
			$args['before'] . $avatar . $byline . $args['after']
		);

		return Gutenix_Utils::output_method( $posted_by_output, $args['echo'] );
	}
endif;

if ( ! function_exists( 'gutenix_post_cats' ) ) :
	/**
	 * Prints HTML with meta information for the current categories.
	 *
	 * @since  1.0.0
	 * @param  array $args Arguments.
	 * @return string|bool
	 */
	function gutenix_post_cats( $args = array() ) {
		if ( 'post' !== get_post_type() ) {
			return false;
		}

		$default_args = array(
			'prefix'    => '',
			'delimiter' => ', ',
			'before'    => '<span class="cat-links">',
			'after'     => '</span>',
			'echo'      => true,
			'visible'   => ! is_singular( 'post' ) ? gutenix_theme()->customizer->get_value( 'blog_post_categories' ) : gutenix_theme()->customizer->get_value( 'single_post_categories' ),

		);

		$args = wp_parse_args( $args, $default_args );
		$args = apply_filters( 'gutenix_post_cats_args', $args );

		if ( empty( $args['delimiter'] ) ) {
			$args['delimiter'] = ' ';
		}

		$visible = filter_var( $args['visible'], FILTER_VALIDATE_BOOLEAN );

		if ( ! $visible ) {
			return false;
		}

		$cats_list = get_the_category_list( esc_html( $args['delimiter'] ) );

		if ( ! $cats_list ) {
			return false;
		}

		if ( ! empty( $args['prefix'] ) ) {
			$args['prefix'] = $args['prefix'] . ' ';
		}

		$output = apply_filters(
			'gutenix_post_cats_output',
			$args['before'] . $args['prefix'] . $cats_list . $args['after']
		);

		return Gutenix_Utils::output_method( $output, $args['echo'] );
	}
endif;

if ( ! function_exists( 'gutenix_post_tags' ) ) :
	/**
	 * Prints HTML with meta information for the current tags.
	 *
	 * @since  1.0.0
	 * @param  array $args Arguments.
	 * @return string|bool
	 */
	function gutenix_post_tags( $args = array() ) {
		if ( 'post' !== get_post_type() ) {
			return false;
		}

		$default_args = array(
			'prefix'    => esc_html_x( 'Tags:', 'post tags prefix', 'gutenix' ),
			'delimiter' => ', ',
			'before'    => '<div class="tags-links">',
			'after'     => '</div>',
			'echo'      => true,
			'visible'   => ! is_singular( 'post' ) ? gutenix_theme()->customizer->get_value( 'blog_post_tags' ) : gutenix_theme()->customizer->get_value( 'single_post_tags' ),
		);

		$args = wp_parse_args( $args, $default_args );
		$args = apply_filters( 'gutenix_post_tags_args', $args );

		$visible = filter_var( $args['visible'], FILTER_VALIDATE_BOOLEAN );

		if ( ! $visible ) {
			return false;
		}

		$tags_list = get_the_tag_list( '', esc_html( $args['delimiter'] ) );

		if ( ! $tags_list ) {
			return false;
		}

		if ( ! empty( $args['prefix'] ) ) {
			$args['prefix'] = $args['prefix'] . ' ';
		}

		$output = apply_filters(
			'gutenix_post_tags_output',
			$args['before'] . $args['prefix'] . $tags_list . $args['after']
		);

		return Gutenix_Utils::output_method( $output, $args['echo'] );
	}
endif;

if ( ! function_exists( 'gutenix_post_comments' ) ) :
	/**
	 * Prints HTML with meta information for the current comments.
	 *
	 * @since  1.0.0
	 * @param  array $args Arguments.
	 * @return string|bool
	 */
	/**
	 * @param array $args
	 *
	 * @return bool|string
	 */
	function gutenix_post_comments( $args = array() ) {
		if ( 'post' !== get_post_type() ) {
			return false;
		}

		$default_args = array(
			'prefix'  => '',
			'suffix'  => esc_html__( 'Comment(s)', 'gutenix' ),
			'before'  => '<span class="comments-link">',
			'after'   => '</span>',
			'echo'    => true,
			'visible' => ! is_singular( 'post' ) ? gutenix_theme()->customizer->get_value( 'blog_post_comments' ) : gutenix_theme()->customizer->get_value( 'single_post_comments' ),
		);

		$args = wp_parse_args( $args, $default_args );
		$args = apply_filters( 'gutenix_post_comments_args', $args );

		$visible = filter_var( $args['visible'], FILTER_VALIDATE_BOOLEAN );

		$post_comments_visible = $visible && ! post_password_required() && ( comments_open() || get_comments_number() );
		$post_comments_visible = apply_filters( 'gutenix_post_comments_visible', $post_comments_visible, $args );

		if ( ! $post_comments_visible ) {
			return false;
		}

		global $post;

		$suffix = $args['suffix'];
		$count  = $post->comment_count . ' ' . $suffix;

		$count_link = sprintf( '<a href="%2$s">%1$s</a>',
			$count,
			esc_url( get_comments_link() )
		);

		if ( ! empty( $args['prefix'] ) ) {
			$args['prefix'] = $args['prefix'] . ' ';
		}

		$comments_output = apply_filters(
			'gutenix_post_comments_output',
			$args['before'] . $args['prefix'] . $count_link . $args['after']
		);

		return Gutenix_Utils::output_method( $comments_output, $args['echo'] );
	}
endif;

if ( ! function_exists( 'gutenix_get_button_markup' ) ) :
	/**
	 * Get button markup.
	 *
	 * @since  1.0.0
	 * @param  array $args Arguments.
	 * @return string
	 */
	function gutenix_get_button_markup( $args = array() ){
		$default_args = array(
			'text'        => '',
			'icon'        => '',
			'url'         => '',
			'is_external' => false,
			'class'       => 'btn',
			'before'      => '',
			'after'       => '',
			'echo'        => false,
			'visible'     => true,
		);

		$args = wp_parse_args( $args, $default_args );
		$args = apply_filters( 'gutenix_button_markup_args', $args );

		$visible = filter_var( $args['visible'], FILTER_VALIDATE_BOOLEAN );

		if ( ! $visible || ! $args['url'] ) {
			return false;
		}

		$target = $args['is_external'] ? ' target="_blank"' : '';

		$format = apply_filters( 'gutenix_button_format', '<a class="%3$s" href="%4$s"%5$s><span class="btn__text">%1$s</span>%2$s</a>' );
		$button = sprintf( $format, $args['text'], $args['icon'], esc_attr( $args['class'] ), esc_url( $args['url'] ), $target );

		$output = apply_filters(
			'gutenix_button_output',
			$args['before'] . $button . $args['after']
		);

		return Gutenix_Utils::output_method( $output, $args['echo'] );
	}
endif;

if ( ! function_exists( 'gutenix_post_button' ) ) :
	/**
	 * Prints HTML with post button.
	 *
	 * @since  1.0.0
	 * @param  array $args Arguments.
	 * @return string|bool
	 */
	function gutenix_post_button( $args = array() ) {
		$default_args = array(
			'icon'    => '',
			'text'    => gutenix_theme()->customizer->get_value( 'blog_read_more_text' ),
			'url'     => get_permalink(),
			'class'   => 'post-button btn btn-default',
			'before'  => '<div class="post-button-wrap">',
			'after'   => '</div>',
			'echo'    => true,
			'visible' => gutenix_theme()->customizer->get_value( 'blog_read_more' ),
		);

		$args = wp_parse_args( $args, $default_args );
		$args = apply_filters( 'gutenix_post_button_args', $args );

		return gutenix_get_button_markup( $args );
	}
endif;

if ( ! function_exists( 'gutenix_entry_meta' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and etc.
	 *
	 * @since  1.0.0
	 * @param  array $args         Arguments.
	 * @param  array $post_modules Modules list: 'post_cats' => array(), 'post_tags' => array(), 'posted_on' => array(), 'posted_by' => array(), 'post_comments' => array(), ...
	 * @return string|bool
	 */
	function gutenix_entry_meta( $args = array(), $post_modules = array() ) {
		if ( empty( $post_modules ) ) {
			return false;
		}

		$default_args = array(
			'before'  => '<div class="entry-meta">',
			'after'   => '</div><!-- .entry-meta -->',
			'divider' => '',
			'echo'    => true,
		);

		$args = wp_parse_args( $args, $default_args );
		$args = apply_filters( 'gutenix_entry_meta_args', $args );

		$output_array = array();

		foreach ( (array) $post_modules as $cb => $cb_args ) {
			$html = '';

			if ( is_callable( $cb ) ) {
				$cb_args = (array) $cb_args;
				$cb_args = wp_parse_args( array( 'echo' => false ), $cb_args );

				$html = call_user_func( $cb, $cb_args );
			}

			if ( ! empty( $html ) ) {
				$output_array[] = $html;
			}
		}

		if ( empty( $output_array ) ) {
			return false;
		}

		$output = join( $args['divider'], $output_array );

		$output = apply_filters( 'gutenix_entry_meta_output',
			$args['before'] . $output . $args['after']
		);

		return Gutenix_Utils::output_method( $output, $args['echo'] );
	}
endif;

if ( ! function_exists( 'gutenix_sticky_label' ) ) :
	/**
	 * Get sticky label HTML grabbed from options.
	 *
	 * @since  1.0.0
	 * @return string|bool
	 */
	function gutenix_get_sticky_label() {
		if ( ! is_sticky() || ! is_home() || is_paged() ) {
			return false;
		}

		$sticky_type = gutenix_theme()->customizer->get_value( 'blog_sticky_type' );

		$icon = apply_filters(
			'gutenix_sticky_label_icon',
			gutenix_get_icon_svg( 'sticky' )
		);

		$label_text   = gutenix_theme()->customizer->get_value( 'blog_sticky_label' );
		$label_format = apply_filters( 'gutenix_sticky_label_text_format', '<span class="sticky-label__text">%s</span>' );
		$label        = sprintf( $label_format, $label_text );

		$content = '';

		switch ( $sticky_type ) {

			case 'icon':
				$content = $icon;
				break;

			case 'label':
				$content = $label;
				break;

			case 'both':
				$content = $icon . $label;
				break;
		}

		if ( empty( $content ) ) {
			return false;
		}

		$format = apply_filters( 'gutenix_sticky_label_format', '<span class="sticky-label sticky-label-type--%2$s">%1$s</span>' );

		return sprintf( $format, $content, $sticky_type );
	}
endif;

if ( ! function_exists( 'gutenix_post_author_bio' ) ) :
	/**
	 * Display box with information about author.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function gutenix_post_author_bio() {

		if ( ! is_singular( 'post' ) ) {
			return;
		}

		if ( is_customize_preview() && ! Gutenix_Utils::is_render_partials() ) {
			echo '<div class="post-author-bio-customize-partial">';
		}

		$is_enabled = gutenix_theme()->customizer->get_value( 'single_author_block' );

		if ( $is_enabled && get_the_author_meta( 'description' ) ) {
			get_template_part( 'template-parts/single/content-author-bio' );
		} elseif ( is_customize_preview() ) {
			echo '<div class="customize-partial-placeholder">' . esc_html__( 'Author Bio Block Placeholder', 'gutenix' ) . '</div>';
		}

		if ( is_customize_preview() && ! Gutenix_Utils::is_render_partials() ) {
			echo '</div>';
		}
	}
endif;

if ( ! function_exists( 'gutenix_post_edit_link' ) ) :
	/**
	 * Prints HTML with edit post link.
	 *
	 * @since  1.0.0
	 * @param  array $args Arguments.
	 * @return string|bool
	 */
	function gutenix_post_edit_link( $args = array() ) {
		$default_args = array(
			'class' => 'btn btn-default',
			'echo'  => true,
		);

		$args = wp_parse_args( $args, $default_args );
		$args = apply_filters( 'gutenix_post_edit_link_args', $args );

		$classes = array( 'post-edit-link' );

		if ( ! empty( $args['class'] ) ) {
			$classes[] = $args['class'];
		}

		ob_start();

		edit_post_link(
			sprintf(
				/* translators: %s: Name of current post */
				esc_html__( 'Edit %s', 'gutenix' ),
				the_title( '<span class="screen-reader-text">"', '"</span>', false )
			),
			'<span class="edit-link">',
			'</span>',
			null,
			esc_attr( join( ' ', $classes ) )
		);

		$output = apply_filters(
			'gutenix_post_edit_link_output',
			ob_get_clean()
		);

		return Gutenix_Utils::output_method( $output, $args['echo'] );
	}
endif;

if ( ! function_exists( 'gutenix_top_message' ) ) :
	/**
	 * Show top panel message.
	 *
	 * @since  1.0.0
	 * @param  string $format Output formatting.
	 * @return void
	 */
	function gutenix_top_message() {
		$message = gutenix_theme()->customizer->get_value( 'top_panel_text' );

		if ( ! $message ) {
			return;
		}

		printf( '<div class="top-panel__message">%s</div>', wp_kses_post( wp_unslash( $message ) ) );
	}
endif;


if ( ! function_exists( 'gutenix_header_logo' ) ) :
	/**
	 * Display the header logo.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function gutenix_header_logo() {

		if ( has_custom_logo() ) {
			$logo 	= get_custom_logo();
			$type 	= 'image';
			$hidden = '';
		} else {
			$hidden = ( display_header_text() == false ) ? ' hidden="hidden"' : '';

			$logo = sprintf( '<a class="site-logo__link" href="%1$s" rel="home">%2$s</a>', esc_url( home_url( '/' ) ), esc_html( get_bloginfo( 'name', 'display' ) ) );
			$type = 'text';
		}

		if ( is_front_page() && is_home() ) {
			$tag = 'h1';
		} else {
			$tag = 'div';
		}

		printf( '<%1$s class="site-logo site-logo--%3$s"%4$s>%2$s</%1$s>', esc_attr( $tag ), wp_kses_post( wp_unslash( $logo ) ), esc_attr( $type ), esc_attr( $hidden ) );
	}
endif;

if ( ! function_exists( 'gutenix_site_description' ) ) :
	/**
	 * Display the site description.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function gutenix_site_description() {
		$show_desc   = gutenix_theme()->customizer->get_value( 'show_tagline' );
		$description = get_bloginfo( 'description', 'display' );

		$visible = $show_desc && $description;

		if ( ! $visible && ! is_customize_preview() ) {
			return;
		}

		$hidden = ! $visible ? ' hidden="hidden"' : '';

		printf( '<div class="site-description"%2$s><span class="site-description__text">%1$s</span></div>', esc_html( $description ), esc_attr( $hidden ) );
	}
endif;

if ( ! function_exists( 'gutenix_header_buttons' ) ) :
	/**
	 * Show header buttons.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function gutenix_header_buttons(){
		$btn_1 = gutenix_get_button_markup( array(
			'visible'     => gutenix_theme()->customizer->get_value( 'show_header_btn_1' ),
			'text'        => gutenix_theme()->customizer->get_value( 'header_btn_text_1' ),
			'url'         => gutenix_theme()->customizer->get_value( 'header_btn_url_1' ),
			'is_external' => gutenix_theme()->customizer->get_value( 'header_btn_external_1' ),
			'class'       => 'btn header-btn header-btn-1',
			'echo'        => false,
		) );

		$btn_2 = gutenix_get_button_markup( array(
			'visible'     => gutenix_theme()->customizer->get_value( 'show_header_btn_2' ),
			'text'        => gutenix_theme()->customizer->get_value( 'header_btn_text_2' ),
			'url'         => gutenix_theme()->customizer->get_value( 'header_btn_url_2' ),
			'is_external' => gutenix_theme()->customizer->get_value( 'header_btn_external_2' ),
			'class'       => 'btn header-btn header-btn-2',
			'echo'        => false,
		) );

		$visible = $btn_1 || $btn_2;

		if ( ! $visible && ! is_customize_preview() ) {
			return;
		}

		$hidden = ! $visible ? ' hidden="hidden"' : '';

		printf( '<div class="header-buttons"%3$s>%1$s%2$s</div>', wp_kses_post( wp_unslash( $btn_1 ) ), wp_kses_post( wp_unslash( $btn_2 ) ), esc_attr( $hidden ) );
	}
endif;

if ( ! function_exists( 'gutenix_footer_logo' ) ) :
	/**
	 * Show footer logo, uploaded from customizer.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function gutenix_footer_logo(){
		$visible = gutenix_theme()->customizer->get_value( 'footer_logo_visible' );

		if ( ! $visible ) {
			return;
		}

		$logo_id = gutenix_theme()->customizer->get_value( 'footer_logo' );

		if ( ! $logo_id ) {
			return;
		}

		$url      = home_url( '/' );
		$alt      = get_bloginfo( 'name' );
		$logo_src = wp_get_attachment_image_src( $logo_id, 'full' );

		if ( ! $logo_src[0] ) {
			return;
		}

		if ( $logo_src[1] && $logo_src[2] ) {
			$atts = ' width="' . esc_attr( $logo_src[1] ) . '" height="' . esc_attr( $logo_src[2] ) . '"';
		} else {
			$atts = '';
		}

		$logo_format = apply_filters(
			'gutenix_footer_logo_format',
			'<div class="footer-logo"><a href="%2$s" class="footer-logo__link"><img src="%1$s" class="footer-logo__img" alt="%3$s"%4$s></a></div>'
		);

		printf( '<div class="footer-logo"><a href="%2$s" class="footer-logo__link"><img src="%1$s" class="footer-logo__img" alt="%3$s"%4$s></a></div>', esc_url( $logo_src[0] ), esc_url( $url ), esc_attr( $alt ), esc_attr( $atts ) );
	}
endif;

if ( ! function_exists( 'gutenix_footer_copyright' ) ) :
	/**
	 * Show footer copyright text.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function gutenix_footer_copyright() {
		$copyright = gutenix_theme()->customizer->get_value( 'footer_copyright' );

		if ( empty( $copyright ) ) {
			return;
		}

		printf( '<div class="footer-copyright">%s</div>', wp_kses_post( Gutenix_Utils::render_macros( wp_unslash( $copyright ) ) ) );
	}
endif;

if ( ! function_exists( 'gutenix_header_search_toggle' ) ) :
	/**
	 * Show header search toggle.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function gutenix_header_search_toggle() {
		$visible = gutenix_theme()->customizer->get_value( 'header_search_visible' );

		if ( ! $visible ) {
			return;
		}
		
		echo '<button class="header-search-toggle btn-initial"><svg class="svg-icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16"><path d="M12.7188 11.3125C13.1667 10.7188 13.5156 10.0625 13.7656 9.34375C14.0156 8.625 14.1406 7.86979 14.1406 7.07812C14.1406 6.09896 13.9531 5.18229 13.5781 4.32812C13.2135 3.46354 12.7083 2.71354 12.0625 2.07812C11.4271 1.43229 10.6771 0.927083 9.8125 0.5625C8.95833 0.1875 8.04688 0 7.07812 0C6.09896 0 5.17708 0.1875 4.3125 0.5625C3.45833 0.927083 2.70833 1.43229 2.0625 2.07812C1.42708 2.71354 0.921875 3.46354 0.546875 4.32812C0.182292 5.18229 0 6.09896 0 7.07812C0 8.04688 0.182292 8.96354 0.546875 9.82812C0.921875 10.6823 1.42708 11.4323 2.0625 12.0781C2.70833 12.7135 3.45833 13.2188 4.3125 13.5938C5.17708 13.9583 6.09896 14.1406 7.07812 14.1406C7.86979 14.1406 8.625 14.0156 9.34375 13.7656C10.0625 13.5156 10.7188 13.1667 11.3125 12.7188L14.2969 15.7031C14.3906 15.8073 14.5 15.8802 14.625 15.9219C14.75 15.974 14.875 16 15 16C15.125 16 15.25 15.974 15.375 15.9219C15.5 15.8802 15.6094 15.8073 15.7031 15.7031C15.901 15.5052 16 15.2708 16 15C16 14.7292 15.901 14.4948 15.7031 14.2969L12.7188 11.3125ZM7.07812 12.1406C6.36979 12.1406 5.70833 12.0104 5.09375 11.75C4.47917 11.4792 3.94271 11.1146 3.48438 10.6562C3.02604 10.1979 2.66146 9.66146 2.39062 9.04688C2.13021 8.43229 2 7.77604 2 7.07812C2 6.36979 2.13021 5.70833 2.39062 5.09375C2.66146 4.47917 3.02604 3.94271 3.48438 3.48438C3.94271 3.02604 4.47917 2.66667 5.09375 2.40625C5.70833 2.13542 6.36979 2 7.07812 2C7.77604 2 8.43229 2.13542 9.04688 2.40625C9.66146 2.66667 10.1979 3.02604 10.6562 3.48438C11.1146 3.94271 11.474 4.47917 11.7344 5.09375C12.0052 5.70833 12.1406 6.36979 12.1406 7.07812C12.1406 7.77604 12.0052 8.43229 11.7344 9.04688C11.474 9.66146 11.1146 10.1979 10.6562 10.6562C10.1979 11.1146 9.66146 11.4792 9.04688 11.75C8.43229 12.0104 7.77604 12.1406 7.07812 12.1406Z"/></svg></button>';

	}
endif;

if ( ! function_exists( 'gutenix_header_search_popup' ) ) :
	/**
	 * Show header search popup.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function gutenix_header_search_popup() {
		$visible = gutenix_theme()->customizer->get_value( 'header_search_visible' );

		if ( ! $visible ) {
			return;
		}

		get_template_part( 'template-parts/header/search-popup' );
	}
endif;

/*
 * Theme actions
 */
if ( ! function_exists( 'gutenix_header_markup' ) ) :
	/**
	 * Header markup.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function gutenix_header_markup(){
		gutenix_theme()->do_location( 'header', 'template-parts/header' );
	}
endif;
add_action( 'gutenix_header', 'gutenix_header_markup' );

if ( ! function_exists( 'gutenix_top_panel_markup' ) ) :
	/**
	 * Top panel markup.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function gutenix_top_panel_markup(){
		get_template_part( 'template-parts/header/top-panel' );
	}
endif;
add_action( 'gutenix_top_panel', 'gutenix_top_panel_markup' );

if ( ! function_exists( 'gutenix_header_bar_markup' ) ) :
	/**
	 * Header bar markup.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function gutenix_header_bar_markup(){
		$layout = gutenix_theme()->customizer->get_value( 'header_layout_type' );

		if ( 'disable' === $layout && ! is_customize_preview() ) {
			return;
		}

		get_template_part( 'template-parts/header/layout', $layout );
	}
endif;
add_action( 'gutenix_header_bar', 'gutenix_header_bar_markup' );

if ( ! function_exists( 'gutenix_footer_markup' ) ) :
	/**
	 * Footer markup.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function gutenix_footer_markup(){
		gutenix_theme()->do_location( 'footer', 'template-parts/footer' );
	}
endif;
add_action( 'gutenix_footer', 'gutenix_footer_markup' );

if ( ! function_exists( 'gutenix_footer_widgets_area_markup' ) ) :
	/**
	 * Footer widgets area markup.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function gutenix_footer_widgets_area_markup(){
		get_template_part( 'template-parts/footer/widgets-area' );
	}
endif;
add_action( 'gutenix_footer_widgets_area', 'gutenix_footer_widgets_area_markup' );

if ( ! function_exists( 'gutenix_footer_bar_markup' ) ) :
	/**
	 * Footer bar markup.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function gutenix_footer_bar_markup(){
		$layout = gutenix_theme()->customizer->get_value( 'footer_layout_type' );

		if ( 'disable' === $layout && ! is_customize_preview() ) {
			return;
		}

		get_template_part( 'template-parts/footer/layout', $layout );
	}
endif;
add_action( 'gutenix_footer_bar', 'gutenix_footer_bar_markup' );
